@@ -1,7 +1,11 @@
 package TAP::Spec::BailOut;
+BEGIN {
+  $TAP::Spec::BailOut::AUTHORITY = 'cpan:ARODLAND';
+}
+{
+  $TAP::Spec::BailOut::VERSION = '0.07_991'; # TRIAL
+}
 # ABSTRACT: A TAP Bail Out! line
-our $VERSION = '0.07_99'; # VERSION
-our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
 use Mouse;
 use namespace::autoclean;
 
@@ -26,6 +30,7 @@ sub as_tap {
 __PACKAGE__->meta->make_immutable;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -34,7 +39,7 @@ TAP::Spec::BailOut - A TAP Bail Out! line
 
 =head1 VERSION
 
-version 0.07_99
+version 0.07_991
 
 =head1 ATTRIBUTES
 
@@ -60,4 +65,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
