@@ -1,7 +1,11 @@
 package TAP::Spec::Body;
+BEGIN {
+  $TAP::Spec::Body::AUTHORITY = 'cpan:ARODLAND';
+}
+{
+  $TAP::Spec::Body::VERSION = '0.07_991'; # TRIAL
+}
 # ABSTRACT: The main body of a TAP testset
-our $VERSION = '0.07_99'; # VERSION
-our $AUTHORITY = 'cpan:ARODLAND'; # AUTHORITY
 use Mouse;
 use namespace::autoclean;
 
@@ -42,6 +46,7 @@ sub as_tap {
 __PACKAGE__->meta->make_immutable;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -50,7 +55,7 @@ TAP::Spec::Body - The main body of a TAP testset
 
 =head1 VERSION
 
-version 0.07_99
+version 0.07_991
 
 =head1 ATTRIBUTES
 
@@ -82,4 +87,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
